@@ -10,88 +10,20 @@
 import ctypes
 import ctypes.util
 import json
-import os
 import sys
 
 import numpy as np
 from numpy.ctypeslib import ndpointer
 
-#
-#  This Python interface needs to find the Magics library
-#
-#  We first search LD_LIBRARY_PATH. If you have strange behaviours,
-#  check your $LD_LIBRARY_PATH.
-#  This is only required on Linux! Therefore we do not have to check
-#  on MacOS the DYLD_LIBRARY_PATH or for *.dylib.
-#
-lib = None
-
 try:
-    import ecmwflibs
+    import ecmwflibs as findlibs
+except ImportError:
+    import findlibs
 
-    lib = ecmwflibs.find("MagPlus")
-except Exception:
-    pass
-
-if sys.platform == "darwin":
-    for directory in os.environ.get("DYLD_LIBRARY_PATH", "").split(":"):
-        fullname = os.path.join(directory, "libMagPlus.dylib")
-        if os.path.exists(fullname):
-            lib = fullname
-            break
-
-    if lib is None:
-        fullname = os.path.join(
-            os.environ.get("MAGPLUS_HOME", ""), "lib/libMagPlus.dylib"
-        )
-        if os.path.exists(fullname):
-            lib = fullname
-
-elif sys.platform == "win32":
-    if lib is None:
-        fullname = os.path.join(
-            os.environ.get("MAGPLUS_HOME", ""), "lib/libMagPlus.dll"
-        )
-        if os.path.exists(fullname):
-            lib = fullname
-
-else:
-    for directory in os.environ.get("LD_LIBRARY_PATH", "").split(":"):
-        fullname = os.path.join(directory, "libMagPlus.so")
-        if os.path.exists(fullname):
-            lib = fullname
-            break
-
-    if lib is None:
-        fullname = os.path.join(os.environ.get("MAGPLUS_HOME", ""), "lib/libMagPlus.so")
-        if os.path.exists(fullname):
-            lib = fullname
-        else:
-            fullname = os.path.join(
-                os.environ.get("MAGPLUS_HOME", ""), "lib64/libMagPlus.so"
-            )
-            if os.path.exists(fullname):
-                lib = fullname
-
-
-#
-#  if not overwritten test if instlled version exist and use it
-#
-# if lib is None:
-#    installname = "@CMAKE_INSTALL_PREFIX@/@INSTALL_LIB_DIR@/libMagPlus@CMAKE_SHARED_LIBRARY_SUFFIX@"
-#    if os.path.exists(installname):
-#        lib = installname
-
-#
-# If LD_LIBRARY_PATH does not contain path to Magics and it is not where you installed,
-# we search the standard system locations
-#
+lib = findlibs.find("MagPlus")
 if lib is None:
-    lib = ctypes.util.find_library("MagPlus")
+    raise RuntimeError("Cannot find MagPlus library")
 
-# as last resort throw exception
-if lib is None:
-    raise Exception("Magics library could not be found")
 
 dll = ctypes.CDLL(lib)
 
@@ -102,7 +34,15 @@ class FILE(ctypes.Structure):
 
 FILE_p = ctypes.POINTER(FILE)
 
-######################## String conversions ##########################
+
+####################################################################
+
+
+def get_library_path():
+    return lib
+
+
+####################################################################
 
 
 def _string_to_char(x):
@@ -142,14 +82,18 @@ def _convert_strings(fn):
     return wrapped
 
 
+def _noop(x):
+    return x
+
+
 if sys.version_info[0] > 2:
     convert_strings = _convert_strings
     char_to_string = _char_to_string
     string_to_char = _string_to_char
 else:
-    convert_strings = lambda x: x
-    char_to_string = lambda x: x
-    string_to_char = lambda x: x
+    convert_strings = _noop
+    char_to_string = _noop
+    string_to_char = _noop
 
 
 ####################################################################
@@ -538,9 +482,9 @@ def eps():
 
 
 ####################################################################
-###
-###  Please note: these two functions changed compared to the previous SWIG based Python interface
-###
+#
+# Please note: these two functions changed compared to the previous SWIG based Python interface
+#
 
 py_metgraph = dll.py_metgraph
 py_metgraph.restype = c_char_p
@@ -561,9 +505,9 @@ def epsinput():
 
 
 ####################################################################
-###
-###  Please note: this function was called mmetbufr to the previous SWIG based Python interface
-###
+#
+# Please note: this function was called mmetbufr to the previous SWIG based Python interface
+#
 
 py_metbufr = dll.py_metbufr
 py_metbufr.restype = c_char_p
@@ -747,7 +691,7 @@ def set1i(name, data):
 
 ####################################################################
 
-array_2d_int = ndpointer(dtype=np.int, ndim=2, flags="CONTIGUOUS")
+array_2d_int = ndpointer(dtype=int, ndim=2, flags="CONTIGUOUS")
 set2i = dll.py_set2i
 set2i.restype = None
 set2i.argtypes = (c_char_p, array_2d_int, c_int, c_int)
@@ -798,9 +742,7 @@ py_set1c.restype = c_char_p
 
 @checked_return_code
 def set1c(name, data):
-    new_data = []
-    for s in data:
-        new_data.append(string_to_char(s))
+    new_data = [string_to_char(s) for s in data]
     name = string_to_char(name)
     data_p = (c_char_p * (len(new_data)))(*new_data)
     return py_set1c(ctypes.c_char_p(name), data_p, len(new_data))
